@@ -4,5 +4,5 @@
 autopoint --force
 aclocal -I m4
 autoheader
-automake --add-missing --gnu --copy
+automake --add-missing --force-missing --gnu --copy
 autoconf
