@@ -34,14 +34,16 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 
+#ifdef USE_DMALLOC
+#include <dmalloc.h>
+#endif
+
 /* own headers */
 #include "globals.h"
 #include "metro.h"
 #include "dsp.h"
 #include "util.h"
 
-int debug;
-
 metro_t* metro;
 
 int main(int argc, char *argv[])
